@@ -9,7 +9,7 @@ use Math::BigNum qw();
 
 use Class::Multimethods qw();
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =encoding utf8
 
@@ -19,7 +19,7 @@ Math::BigNum::Inf - Represents the +/-Infinity value.
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =head1 SYNOPSIS
 
@@ -1166,6 +1166,18 @@ Square root of C<$x>.
 *sqrt  = \&inf;
 *isqrt = \&sqrt;
 
+sub isqrtrem {
+    my ($x) = @_;
+    my $sqrt = $x->isqrt;
+    ($sqrt, $x->isub($sqrt->bimul($sqrt)));
+}
+
+sub irootrem {
+    my ($x, $y) = @_;
+    my $root = $x->iroot($y);
+    ($root, $x->isub($root->bipow($y)));
+}
+
 =head2 bsqrt / bisqrt
 
 Square root of C<$x>, changing C<$x> in-place.
@@ -1424,6 +1436,10 @@ is always Nan.
 *not  = \&nan;
 *bnot = \&bnan;
 
+*beta     = \&nan;
+*bessel_j = \&nan;
+*bessel_y = \&nan;
+
 =head2 lsft
 
     $x->lsft(BigNum)               # => Inf
@@ -1585,11 +1601,15 @@ Class::Multimethods::multimethod brsft => qw(Math::BigNum::Inf Math::BigNum::Nan
 *dec  = \&copy;
 *bdec = \&_self;
 
-*li   = \&inf;
-*li2  = \&ninf;
-*lgrt = \&inf;
-*ln   = \&inf;
-*bln  = \&binf;
+*li        = \&inf;
+*li2       = \&ninf;
+*lgrt      = \&inf;
+*lambert_w = \&inf;
+*ln        = \&inf;
+*bln       = \&binf;
+
+*rad2deg = \&copy;
+*deg2rad = \&copy;
 
 *bernreal  = \&nan;
 *bernfrac  = \&nan;
@@ -1649,6 +1669,8 @@ sub zeta {
     $_[0]->is_neg ? nan() : one();
 }
 
+*eta = \&zeta;
+
 sub erfc {
     $_[0]->is_pos ? zero() : one()->blsft(1);
 }
