@@ -7,7 +7,7 @@ use warnings;
 use Math::GMPq qw();
 use Math::BigNum qw();
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =encoding utf8
 
@@ -17,7 +17,7 @@ Math::BigNum::Nan - Represents the Not-a-Number value.
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =head1 SYNOPSIS
 
@@ -371,7 +371,9 @@ sub cmp { }
 *coth  = \&nan;
 *acoth = \&nan;
 *atan2 = \&nan;
-*lgrt  = \&nan;
+
+*lgrt      = \&nan;
+*lambert_w = \&nan;
 
 *rand   = \&nan;
 *irand  = \&nan;
@@ -468,19 +470,29 @@ sub length { 0 }
 *lngamma    = \&nan;
 *lgamma     = \&nan;
 *digamma    = \&nan;
+*beta       = \&nan;
 *zeta       = \&nan;
+*eta        = \&nan;
 *erf        = \&nan;
 *erfc       = \&nan;
 *eint       = \&nan;
 *li         = \&nan;
 *li2        = \&nan;
 
+*bessel_j = \&nan;
+*bessel_y = \&nan;
+
+*rad2deg = \&nan;
+*deg2rad = \&nan;
+
 *numerator   = \&nan;
 *denominator = \&nan;
 
 sub divmod { (nan(), nan()) }
 
-*parts = \&divmod;
+*parts    = \&divmod;
+*isqrtrem = \&divmod;
+*irootrem = \&divmod;
 
 sub seed { }
 *iseed = \&seed;
